| Title: | Implementation of MVMR-cML-SuSiE |
|---|---|
| Description: | Implements the first three steps of constrained Maximum Likelihood (cML) based Mendelian randomization approach for highly correlated exposures |
| Authors: | Lap Sum Chan |
| Maintainer: | Lap Sum Chan <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.0 |
| Built: | 2026-05-14 05:54:28 UTC |
| Source: | https://github.com/lapsumchan/MVMR-cML-SuSiE |
This function performs the first step of the MVMR-cML-SuSiE approach to obtain each exposure's univariable
Mendelian randomization (UVMR) p-value, used for initial filtering of exposures. You can choose to pull
GWAS data using OpenGWAS (by setting use.openGWAS = TRUE) or provide your own summary
statistics (by setting use.openGWAS = FALSE)
mvmr.cml.susie.step1( exposure.ids = NULL, outcome.id = NULL, sample.sizes, beta.exposure.ls = NULL, se.exposure.ls = NULL, beta.outcome.ls = NULL, se.outcome.ls = NULL, use.openGWAS = TRUE )mvmr.cml.susie.step1( exposure.ids = NULL, outcome.id = NULL, sample.sizes, beta.exposure.ls = NULL, se.exposure.ls = NULL, beta.outcome.ls = NULL, se.outcome.ls = NULL, use.openGWAS = TRUE )
exposure.ids |
A length |
outcome.id |
A character corresponding to the outcome openGWAS ID |
sample.sizes |
A numeric vector of sample sizes corresponding to each exposure and outcome
If |
beta.exposure.ls |
A list (length |
se.exposure.ls |
A list (length |
beta.outcome.ls |
A list (length |
se.outcome.ls |
A list (length |
use.openGWAS |
A logical indicating whether to use |
A numeric vector (length ) of p-values, each corresponding to the UVMR p-value for one exposure
This function performs the second step of the MVMR-cML-SuSiE approach. After identifying exposures of interest in Step 1 (e.g., by filtering UVMR p-values), step 2 extracts the relevant instruments for those exposures, identifies invalid instruments (if any), and obtains an initial estimate from univariable Mendelian randomization (UVMR) for each exposure
mvmr.cml.susie.step2( exposure.ids.subset = NULL, outcome.id = NULL, sample.sizes.subset, beta.exposure.mat = NULL, se.exposure.mat = NULL, beta.outcome.vec = NULL, se.outcome.vec = NULL, pval.exposure.mat = NULL, use.openGWAS = TRUE, cutoff = 5e-08 )mvmr.cml.susie.step2( exposure.ids.subset = NULL, outcome.id = NULL, sample.sizes.subset, beta.exposure.mat = NULL, se.exposure.mat = NULL, beta.outcome.vec = NULL, se.outcome.vec = NULL, pval.exposure.mat = NULL, use.openGWAS = TRUE, cutoff = 5e-08 )
exposure.ids.subset |
A length |
outcome.id |
A character specifying the outcome ID |
sample.sizes.subset |
A length |
beta.exposure.mat |
A size |
se.exposure.mat |
A size |
beta.outcome.vec |
A length |
se.outcome.vec |
A length |
pval.exposure.mat |
A |
use.openGWAS |
A logical indicating whether to extract data via |
cutoff |
A numeric threshold for instrument selection. Default is |
A list containing:
mvdat |
A list containing the relevant data (exposure/outcome betas, SEs, etc) |
invalid.idx |
A vector of indices of invalid instruments identified based off the UVMR procedure |
theta.vec |
A numeric vector of initial values for each exposure |
This function performs the iterative SuSiE algorithm to identify potential exposure signal clusters
mvmr.cml.susie.step3( mvdat, invalid.idx, theta.vec, rho.mat, S = 10, max.iter = 200, tol = 1e-10 )mvmr.cml.susie.step3( mvdat, invalid.idx, theta.vec, rho.mat, S = 10, max.iter = 200, tol = 1e-10 )
mvdat |
A list returned by |
invalid.idx |
An integer vector of invalid IV indices as identified in step 2 |
theta.vec |
A numeric vector of initial exposure effect estimates from step 2 |
rho.mat |
A genetic correlation matrix of size |
S |
The number of single effects (signal clusters) in SuSiE. Default is 10. |
max.iter |
The maximum number of iterations for SuSiE. Default is 200. |
tol |
A numeric value indicating the convergence threshold for the iterative procedure. Default is |
A fitted susie object. The key SuSiE output is the posterior inclusion probability (PIP) matrix alpha
used for determining signal clusters